@@ -324,8 +324,8 @@ public:
 				break;
 
 			if(becho) {
-				printf("processing node %d\n", nnode+1);
-				printf("    [#parents][#combinations] = ");
+				Rprintf("processing node %d\n", nnode+1);
+				Rprintf("    [#parents][#combinations] = ");
 			}
 
 			fixparsetsize = 0;
@@ -422,7 +422,7 @@ public:
 					}
 			
 					if(becho)
-						printf("[%d]%d  ", d, ncomblist);
+						Rprintf("[%d]%d  ", d, ncomblist);
 
 					fMaxLogLik = -FLT_MAX;
 					ncombMaxLogLik = -1;
@@ -546,7 +546,7 @@ public:
 				}
 			
 				if(becho)
-					printf("[%d]%d  ", d, ncomblist);
+					Rprintf("[%d]%d  ", d, ncomblist);
 
 				fMaxLogLik = -FLT_MAX;
 				ncombMaxLogLik = -1;
@@ -643,7 +643,7 @@ public:
 			} /* if(!bEqualCategories) */
 
 			if(becho)
-				printf("\n");
+				Rprintf("\n");
 
 			for(j = 0; j < m_nCatnets; j++) {
 				if(m_pCatnets[j]) {
@@ -865,8 +865,8 @@ public:
 				break;
 
 			if(becho) {
-				printf("processing node %d\n", nnode+1);
-				printf("    [#parents][#combinations] = ");
+				Rprintf("processing node %d\n", nnode+1);
+				Rprintf("    [#parents][#combinations] = ");
 			}
 
 			fixparsetsize = 0;
@@ -963,7 +963,7 @@ public:
 					}
 			
 					if(becho)
-						printf("[%d]%d  ", d, ncomblist);
+						Rprintf("[%d]%d  ", d, ncomblist);
 
 					fMaxLogLik = -FLT_MAX;
 					ncombMaxLogLik = -1;
@@ -1087,7 +1087,7 @@ public:
 				}
 			
 				if(becho)
-					printf("[%d]%d  ", d, ncomblist);
+					Rprintf("[%d]%d  ", d, ncomblist);
 
 				fMaxLogLik = -FLT_MAX;
 				ncombMaxLogLik = -1;
@@ -1184,7 +1184,7 @@ public:
 			} /* if(!bEqualCategories) */
 
 			if(becho)
-				printf("\n");
+				Rprintf("\n");
 
 			for(j = 0; j < m_nCatnets; j++) {
 				if(m_pCatnets[j]) {
